@@ -11,19 +11,22 @@ _LOGGER = logging.getLogger(__name__)
 CHARACTERISTIC_COMMAND_WRITE = "0000ffe9-0000-1000-8000-00805f9b34fb"
 CHARACTERISTIC_NOTIFY_VALUE = "0000ffe4-0000-1000-8000-00805f9b34fb"
 
-NOTIFICATION_RESPONSE_TIMEOUT = 5
+# Default to a 5s timeout on remote calls
+DEFAULT_TIMEOUT = 5
 
 
 class Light():
     """Represents one connected light"""
 
-    def __init__(self, address, name=None):
+    def __init__(self, address, name=None, *args,
+                 default_timeout=DEFAULT_TIMEOUT):
         import bleak
 
         self._address = address
         self._name = name
         self._client = bleak.BleakClient(self._address)
         self._notification_queue = asyncio.Queue(maxsize=1)
+        self._default_timeout = DEFAULT_TIMEOUT
 
     @property
     def address(self):
@@ -35,51 +38,75 @@ class Light():
         """Return the discovered name of this light."""
         return self._name
 
-    async def is_connected(self, *args, timeout=10):
+    async def is_connected(self, *args, timeout=None):
         """Returns true if the light is connected."""
         try:
-            return await asyncio.wait_for(self._client.is_connected(), timeout)
+            return await asyncio.wait_for(
+                self._client.is_connected(),
+                self._default_timeout if timeout is None else timeout)
         except asyncio.TimeoutError:
             return False
         except Exception as ex:
             raise ZerprocException() from ex
 
-    async def connect(self):
+    async def _do_connect(self):
+        """Connect to this light"""
+        await self._client.connect()
+        await self._client.start_notify(
+            CHARACTERISTIC_NOTIFY_VALUE, self._handle_data)
+
+    async def _do_disconnect(self):
+        """Close the connection to the light."""
+        await self._client.stop_notify(CHARACTERISTIC_NOTIFY_VALUE)
+        await self._client.disconnect()
+
+    async def connect(self, *args, timeout=None):
         """Connect to this light"""
         _LOGGER.debug("Connecting to %s", self._address)
 
         try:
-            await self._client.connect()
-            await self._client.start_notify(
-                CHARACTERISTIC_NOTIFY_VALUE, self._handle_data)
+            await asyncio.wait_for(
+                self._do_connect(),
+                self._default_timeout if timeout is None else timeout)
         except Exception as ex:
             raise ZerprocException() from ex
 
         _LOGGER.debug("Connected to %s", self._address)
 
-    async def disconnect(self):
+    async def disconnect(self, *args, timeout=None):
         """Close the connection to the light."""
         _LOGGER.debug("Disconnecting from %s", self._address)
         try:
-            await self._client.stop_notify(CHARACTERISTIC_NOTIFY_VALUE)
-            await self._client.disconnect()
+            await asyncio.wait_for(
+                self._do_disconnect(),
+                self._default_timeout if timeout is None else timeout)
         except Exception as ex:
             raise ZerprocException() from ex
         _LOGGER.debug("Disconnected from %s", self._address)
 
-    async def turn_on(self):
+    async def turn_on(self, *args, timeout=None):
         """Turn on the light"""
         _LOGGER.info("Turning on %s", self._address)
-        await self._write(CHARACTERISTIC_COMMAND_WRITE, b'\xCC\x23\x33')
+        try:
+            await asyncio.wait_for(
+                self._write(CHARACTERISTIC_COMMAND_WRITE, b'\xCC\x23\x33'),
+                self._default_timeout if timeout is None else timeout)
+        except asyncio.TimeoutError as ex:
+            raise ZerprocException() from ex
         _LOGGER.debug("Turned on %s", self._address)
 
-    async def turn_off(self):
+    async def turn_off(self, *args, timeout=None):
         """Turn off the light"""
         _LOGGER.info("Turning off %s", self._address)
-        await self._write(CHARACTERISTIC_COMMAND_WRITE, b'\xCC\x24\x33')
+        try:
+            await asyncio.wait_for(
+                self._write(CHARACTERISTIC_COMMAND_WRITE, b'\xCC\x24\x33'),
+                self._default_timeout if timeout is None else timeout)
+        except asyncio.TimeoutError as ex:
+            raise ZerprocException() from ex
         _LOGGER.debug("Turned off %s", self._address)
 
-    async def set_color(self, r, g, b):
+    async def set_color(self, r, g, b, *args, timeout=None):
         """Set the color of the light
 
         Accepts red, green, and blue values from 0-255
@@ -100,12 +127,17 @@ class Light():
         b = 255 if b == 255 else int(math.ceil(b * 31 / 255))
 
         if r == 0 and g == 0 and b == 0:
-            await self.turn_off()
+            await self.turn_off(timeout=timeout)
         else:
             color_string = bytes((r, g, b))
 
             value = b'\x56' + color_string + b'\x00\xF0\xAA'
-            await self._write(CHARACTERISTIC_COMMAND_WRITE, value)
+            try:
+                await asyncio.wait_for(
+                    self._write(CHARACTERISTIC_COMMAND_WRITE, value),
+                    self._default_timeout if timeout is None else timeout)
+            except asyncio.TimeoutError as ex:
+                raise ZerprocException() from ex
             _LOGGER.debug("Changed color of %s", self._address)
 
     def _handle_data(self, handle, value):
@@ -116,7 +148,7 @@ class Light():
         except asyncio.QueueFull:
             _LOGGER.debug("Discarding duplicate response", exc_info=True)
 
-    async def get_state(self):
+    async def _do_get_state(self):
         """Get the current state of the light"""
         # Clear the queue if a value is somehow left over
         try:
@@ -126,12 +158,7 @@ class Light():
 
         await self._write(CHARACTERISTIC_COMMAND_WRITE, b'\xEF\x01\x77')
 
-        try:
-            response = await asyncio.wait_for(
-                self._notification_queue.get(),
-                timeout=NOTIFICATION_RESPONSE_TIMEOUT)
-        except asyncio.TimeoutError as ex:
-            raise ZerprocException("Timeout waiting for response") from ex
+        response = await self._notification_queue.get()
 
         on_off_value = int(response[2])
 
@@ -157,6 +184,15 @@ class Light():
 
         return state
 
+    async def get_state(self, *args, timeout=None):
+        """Get the current state of the light"""
+        try:
+            return await asyncio.wait_for(
+                self._do_get_state(),
+                self._default_timeout if timeout is None else timeout)
+        except asyncio.TimeoutError as ex:
+            raise ZerprocException() from ex
+
     async def _write(self, uuid, value):
         """Internal method to write to the device"""
         _LOGGER.debug("Writing 0x%s to characteristic %s", value.hex(), uuid)
